void csamlmr(double *x, int n, double *xmom, int nmom, double a, double b);
extern void samlmr_();

void csamlmu(double *x, int n, double *xmom, int nmom);
extern void samlmu_();

void csampwm(double *x, int n, double *xmom, int nmom, double a, double b, int kind);
extern void sampwm_();

double ccdfexp(double *x, double *para);
extern double cdfexp_();

double cquaexp(double *f, double *para);
extern double quaexp_();

void clmrexp(double *para, double *xmom, int nmom);
extern void lmrexp_();

void cpelexp(double *xmom, double *para);
extern void pelexp_();

double ccdfgam(double *x, double *para);
extern double cdfgam_();

double cquagam(double *f, double *para);
extern double quagam_();

void clmrgam(double *para, double *xmom, int nmom);
extern void lmrgam_();

void cpelgam(double *xmom, double *para);
extern void pelgam_();

double ccdfgev(double *x, double *para);
extern double cdfgev_();

double cquagev(double *f, double *para);
extern double quagev_();

void clmrgev(double *para, double *xmom, int nmom);
extern void lmrgev_();

void cpelgev(double *xmom, double *para);
extern void pelgev_();

double ccdfglo(double *x, double *para);
extern double cdfglo_();

double cquaglo(double *f, double *para);
extern double quaglo_();

void clmrglo(double *para, double *xmom, int nmom);
extern void lmrglo_();

void cpelglo(double *xmom, double *para);
extern void pelglo_();

double ccdfgno(double *x, double *para);
extern double cdfgno_();

double cquagno(double *f, double *para);
extern double quagno_();

void clmrgno(double *para, double *xmom, int nmom);
extern void lmrgno_();

void cpelgno(double *xmom, double *para);
extern void pelgno_();

double ccdfgpa(double *x, double *para);
extern double cdfgpa_();

double cquagpa(double *f, double *para);
extern double quagpa_();

void clmrgpa(double *para, double *xmom, int nmom);
extern void lmrgpa_();

void cpelgpa(double *xmom, double *para);
extern void pelgpa_();

double ccdfgum(double *x, double *para);
extern double cdfgum_();

double cquagum(double *f, double *para);
extern double quagum_();

void clmrgum(double *para, double *xmom, int nmom);
extern void lmrgum_();

void cpelgum(double *xmom, double *para);
extern void pelgum_();

double ccdfkap(double *x, double *para);
extern double cdfkap_();

double cquakap(double *f, double *para);
extern double quakap_();

void clmrkap(double *para, double *xmom, int nmom);
extern void lmrkap_();

void cpelkap(double *xmom, double *para, int *ifail);
extern void pelkap_();

double ccdfnor(double *x, double *para);
extern double cdfnor_();

double cquanor(double *f, double *para);
extern double quanor_();

void clmrnor(double *para, double *xmom, int nmom);
extern void lmrnor_();

void cpelnor(double *xmom, double *para);
extern void pelnor_();

double ccdfpe3(double *x, double *para);
extern double cdfpe3_();

double cquape3(double *f, double *para);
extern double quape3_();

void clmrpe3(double *para, double *xmom, int nmom);
extern void lmrpe3_();

void cpelpe3(double *xmom, double *para);
extern void pelpe3_();

double ccdfwak(double *x, double *para);
extern double cdfwak_();

double cquawak(double *f, double *para);
extern double quawak_();

void clmrwak(double *para, double *xmom, int nmom);
extern void lmrwak_();

void cpelwak(double *xmom, double *para, int *ifail);
extern void pelwak_();
